﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace RowSelectorTooltips
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // Create a UltraToolTipContextHelperForGrid to show tooltips for the row selector
            // when there's a RowError. 
            var tooltipContextHelper = new UltraToolTipContextHelperForGrid(this.ultraGrid1, this.ultraToolTipManager1);

            this.ultraGrid1.InitializeLayout += UltraGrid1_InitializeLayout;
            this.ultraGrid1.InitializeRow += UltraGrid1_InitializeRow;
            var dt = DummyDataCreator.GetData(20);
            dt.Rows[1].RowError = "This is a row error for row 1";
            dt.Rows[5].RowError = "This is a row error for row 5";
            this.ultraGrid1.SetDataBinding(dt, null);
        }

        private void UltraGrid1_InitializeRow(object sender, Infragistics.Win.UltraWinGrid.InitializeRowEventArgs e)
        {
            // Display an image in the RowSelector for rows that have a RowError. 
            var row = e.Row;
            var rowError = UltraToolTipContextHelperForGrid.GetRowError(row);
            if (string.IsNullOrEmpty(rowError))
                row.RowSelectorAppearance.Reset();
            else
                row.RowSelectorAppearance = row.Band.Layout.Appearances["RowSelectorErrorAppearance"];
        }

        private void UltraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            var layout = e.Layout;
            var band = layout.Bands[0];
            var ov = layout.Override;

            var rowSelectorErrorAppearance = layout.Appearances.Add("RowSelectorErrorAppearance");
            rowSelectorErrorAppearance.Image = SystemIcons.Error.ToBitmap();

            // There's no way to turn off the default tooltips for DataError. So we can't use this
            // becuase if we do, we get double-tooltips when you mouse over the icon. 
            // Instead, we will apply an appearance to the RowSelector in InitializeRow. 
            //
            //ov.SupportDataErrorInfo = Infragistics.Win.UltraWinGrid.SupportDataErrorInfo.RowsAndCells;            

            ov.RowSelectors = Infragistics.Win.DefaultableBoolean.True;
            ov.RowSelectorNumberStyle = Infragistics.Win.UltraWinGrid.RowSelectorNumberStyle.RowIndex;
        }
    }
}
