using System;
using System.Windows.Forms;
using System.Drawing;
using System.Data;

using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win.UltraWinToolTip;

	/// <summary>
	/// This class derives from UltraToolTipContextHelperBase. The base class
	/// handles events of the control and calls the PrepareToolTip abstract method
	/// any time it needs to evaluate whether to show a tooltip for a 
	/// particular UIElement.
	///  
	/// This class overrides PrepareToolTip and checkes for certain types
	/// of elements, such as CellUIElement, HeaderUIElement, DataErrorIconUIElement,
	/// and GroupByRowUIElement and sets text, title, and image on the tooltip.
	/// </summary>
public class UltraToolTipContextHelperForGrid : UltraToolTipContextHelperBase
{
	#region Constructor
	public UltraToolTipContextHelperForGrid(UltraGrid grid, UltraToolTipManager toolTipManager)  : base(grid, toolTipManager)
	{		
	}
	#endregion Constructor

	#region Overrides

	#region PrepareToolTip
	protected override bool PrepareToolTip(Infragistics.Win.UIElement element, Infragistics.Win.UltraWinToolTip.UltraToolTipInfo toolTipInfo)
	{
        // See if this is a RowSelector. 
        if (this.PrepareRowSelectorToolTip(element, toolTipInfo))
            return true;        
		        
		// Since the element was not one of the types being checked for, 
		// return false so no tooltip will be shown.
		return false;
	}
	#endregion PrepareToolTip

	#endregion Overrides

	#region Private Methods

    #region PrepareRowSelectorToolTip
    private bool PrepareRowSelectorToolTip(Infragistics.Win.UIElement element, Infragistics.Win.UltraWinToolTip.UltraToolTipInfo toolTipInfo)
    {
        // See if the element is a RowSelectorUIElement
        RowSelectorUIElement rowSelectorElement = element as RowSelectorUIElement;

        // If it's not a RowSelectorUIElement, return false.
        if (rowSelectorElement == null)
            return false;

        // Get the Row from the RowSelectorUIElement
        UltraGridRow row = rowSelectorElement.GetContext(typeof(UltraGridRow)) as UltraGridRow;
        var rowError = UltraToolTipContextHelperForGrid.GetRowError(row);
        if (string.IsNullOrEmpty(rowError))
            return false;

        toolTipInfo.ToolTipText = rowError;
        toolTipInfo.ToolTipImage = ToolTipImage.Error;

        // Return true to indicate that a tooltip should be displayed when the
        // mouse is over this element.
        return true;
    }
    #endregion PrepareRowSelectorToolTip


    public static string GetRowError(UltraGridRow row)
    {
        var dataErrorInfoResolved = row.DataErrorInfoResolved;
        if (null == dataErrorInfoResolved)
            return null;

        var rowError = dataErrorInfoResolved.RowError;
        if (string.IsNullOrEmpty(rowError))
            return null;

        return rowError;
    }
    #endregion Private Methods
}
